<?php
/** ‪Chinese (Macau) (‪中文(澳門)‬)
 *
 * See MessagesQqq.php for message documentation incl. usage of parameters
 * To improve a translation please visit http://translatewiki.net
 *
 * @ingroup Language
 * @file
 *
 */

# Inherit everything for now
$fallback = 'zh-hk, zh-hant, zh-hans';
